//
//  SovereignStateNeighbors.swift
//  
//
//  Created by Evan Anderson on 7/9/22.
//

import Foundation

internal enum SovereignStateNeighbors { // https://en.wikipedia.org/wiki/List_of_countries_and_territories_by_land_and_maritime_borders
    static func get(_ country: Country) -> [Country]? {
        switch country {
        case .abkhazia: return [Country.russia, Country.georgia, Country.turkey]
        case .afghanistan: return [Country.china, Country.iran, Country.pakistan, Country.tajikistan, Country.turkmenistan, Country.uzbekistan]
        case .albania: return [Country.greece, Country.italy, Country.kosovo, Country.montenegro, Country.north_macedonia]
        case .algeria: return [Country.france, Country.italy, Country.libya, Country.mali, Country.mauritania, Country.morocco, Country.niger, Country.spain, Country.tunisia, Country.western_sahara]
        case .american_samoa: return [Country.cook_islands, Country.niue, Country.tokelau, Country.tonga]
        case .andorra: return [Country.france, Country.spain]
        case .angola: return [Country.democratic_republic_of_the_congo, Country.republic_of_the_congo, Country.namibia, Country.zambia]
        case .anguilla: return [Country.antigua_and_barbuda, Country.british_virgin_islands, Country.netherlands, Country.saint_barthelemy, Country.saint_martin]

        case .antigua_and_barbuda: return [Country.anguilla, Country.france, Country.montserrat, Country.saint_barthelemy, Country.saint_kitts_and_nevis]
        case .argentina: return [Country.bolivia, Country.brazil, Country.chile, Country.falkland_islands, Country.paraguay, Country.uruguay]
        case .artsakh: return [Country.armenia, Country.azerbaijan]
        case .armenia: return [Country.azerbaijan, Country.georgia, Country.iran, Country.turkey]
        case .aruba: return [Country.dominican_republic, Country.venezuela]
        case .australia: return [Country.indonesia, Country.new_zealand, Country.papua_new_guinea, Country.solomon_islands, Country.timor_leste]
        case .austria: return [Country.czech_republic, Country.germany, Country.hungary, Country.italy, Country.liechtenstein, Country.slovakia, Country.slovenia, Country.switzerland]
        case .azerbaijan: return [Country.armenia, Country.georgia, Country.iran, Country.kazakhstan, Country.russia, Country.turkey, Country.turkmenistan]

        case .bahamas: return [Country.cuba, Country.haiti, Country.turks_and_caicos_islands, Country.united_states]
        case .bahrain: return [Country.iran, Country.qatar, Country.saudi_arabia]
        case .bangladesh: return [Country.india, Country.myanmar]
        case .barbados: return [Country.france, Country.guyana, Country.saint_lucia, Country.saint_vincent_and_the_grenadines, Country.trinidad_and_tobago, Country.venezuela]
        case .belarus: return [Country.latvia, Country.lithuania, Country.poland, Country.russia, Country.ukraine]
        case .belgium: return [Country.france, Country.germany, Country.luxembourg, Country.netherlands, Country.united_kingdom]
        case .belize: return [Country.guatemala, Country.honduras, Country.mexico]
        case .benin: return [Country.burkina_faso, Country.niger, Country.nigeria, Country.togo]
        case .bermuda: return nil
        case .bhutan: return [Country.china, Country.india]
        case .bolivia: return [Country.argentina, Country.brazil, Country.chile, Country.paraguay, Country.peru]
        case .bosnia_and_herzegovina: return [Country.croatia, Country.montenegro, Country.serbia]
        case .botswana: return [Country.namibia, Country.south_africa, Country.zambia, Country.zimbabwe]
        case .brazil: return [Country.argentina, Country.bolivia, Country.colombia, Country.france, Country.guyana, Country.paraguay, Country.peru, Country.suriname, Country.uruguay, Country.venezuela]
        case .british_virgin_islands: return [Country.anguilla, Country.puerto_rico]
        case .brunei: return [Country.china, Country.malaysia, Country.philippines, Country.taiwan, Country.vietnam]
        case .bulgaria: return [Country.georgia, Country.greece, Country.north_macedonia, Country.romania, Country.serbia, Country.turkey]
        case .burkina_faso: return [Country.benin, Country.ivory_coast, Country.ghana, Country.mali, Country.niger, Country.togo]
        case .burundi: return [Country.democratic_republic_of_the_congo, Country.rwanda, Country.tanzania]

        case .cambodia: return [Country.laos, Country.thailand, Country.vietnam]
        case .cameroon: return [Country.central_african_republic, Country.chad, Country.republic_of_the_congo, Country.gabon, Country.nigeria]
        case .canada: return [Country.greenland, Country.saint_pierre_and_miquelon, Country.united_states]
        case .cape_verde: return [Country.gambia, Country.mauritania, Country.senegal]
        case .cayman_islands: return [Country.cuba, Country.honduras, Country.jamaica]
        case .central_african_republic: return [Country.cameroon, Country.chad, Country.democratic_republic_of_the_congo, Country.republic_of_the_congo, Country.south_sudan, Country.sudan]
        case .chad: return [Country.cameroon, Country.central_african_republic, Country.libya, Country.niger, Country.nigeria, Country.sudan]
        case .chile: return [Country.argentina, Country.bolivia, Country.peru]
        case .china: return [Country.afghanistan, Country.bhutan, Country.brunei, Country.hong_kong, Country.india, Country.indonesia, Country.japan, Country.kazakhstan, Country.north_korea, Country.south_korea, Country.kyrgyzstan, Country.laos, Country.macau, Country.malaysia, Country.mongolia, Country.myanmar, Country.nepal, Country.pakistan, Country.philippines, Country.russia, Country.taiwan, Country.tajikistan, Country.vietnam]
        case .colombia: return [Country.brazil, Country.costa_rica, Country.dominican_republic, Country.ecuador, Country.haiti, Country.jamaica, Country.nicaragua, Country.panama, Country.peru, Country.venezuela]
        case .comoros: return [Country.france, Country.madagascar, Country.mozambique, Country.seychelles, Country.tanzania]
        case .cook_islands: return [Country.american_samoa, Country.kiribati, Country.niue, Country.tokelau]
        case .democratic_republic_of_the_congo: return [Country.angola, Country.burundi, Country.central_african_republic, Country.republic_of_the_congo, Country.rwanda, Country.south_sudan, Country.tanzania, Country.uganda, Country.zambia]
        case .republic_of_the_congo: return [Country.angola, Country.cameroon, Country.central_african_republic, Country.democratic_republic_of_the_congo, Country.gabon]
        case .costa_rica: return [Country.colombia, Country.ecuador, Country.nicaragua, Country.panama]
        case .ivory_coast: return [Country.burkina_faso, Country.ghana, Country.guinea, Country.liberia, Country.mali]
        case .croatia: return [Country.bosnia_and_herzegovina, Country.hungary, Country.italy, Country.montenegro, Country.serbia, Country.slovenia]
        case .cuba: return [Country.bahamas, Country.cayman_islands, Country.haiti, Country.honduras, Country.jamaica, Country.mexico, Country.united_states]
        case .cyprus: return [Country.egypt, Country.greece, Country.israel, Country.lebanon, Country.northern_cyprus, Country.syria, Country.turkey]
        case .czech_republic: return [Country.austria, Country.germany, Country.poland, Country.slovakia]

        case .denmark: return [Country.germany, Country.norway, Country.poland, Country.sweden, Country.united_kingdom]
        case .djibouti: return [Country.eritrea, Country.ethiopia, Country.somaliland, Country.yemen]
        case .dominica: return [Country.france, Country.venezuela]
        case .dominican_republic: return [Country.aruba, Country.colombia, Country.haiti, Country.puerto_rico, Country.turks_and_caicos_islands, Country.venezuela]

        case .timor_leste: return [Country.australia, Country.indonesia]
        case .ecuador: return [Country.colombia, Country.costa_rica, Country.peru]
        case .egypt: return [Country.cyprus, Country.greece, Country.israel, Country.jordan, Country.libya, Country.saudi_arabia, Country.sudan, Country.turkey, Country.palestine]
        case .el_salvador: return [Country.guatemala, Country.honduras, Country.nicaragua]
        case .eritrea: return [Country.djibouti, Country.ethiopia, Country.saudi_arabia, Country.sudan, Country.yemen]
        case .estonia: return [Country.finland, Country.latvia, Country.russia, Country.sweden]
        case .eswatini: return [Country.mozambique, Country.south_africa]
        case .ethiopia: return [Country.djibouti, Country.eritrea, Country.kenya, Country.somaliland, Country.south_sudan, Country.sudan]

        case .falkland_islands: return [Country.argentina]
        case .fiji: return [Country.new_zealand, Country.solomon_islands, Country.tonga, Country.tuvalu, Country.vanuatu, Country.wallis_and_futuna]
        case .finland: return [Country.estonia, Country.norway, Country.russia, Country.sweden]
        case .france: return [Country.algeria, Country.andorra, Country.antigua_and_barbuda, Country.barbados, Country.belgium, Country.brazil, Country.comoros, Country.dominica, Country.germany, Country.guernsey, Country.italy, Country.jersey, Country.luxembourg, Country.madagascar, Country.mauritius, Country.monaco, Country.montserrat, Country.saint_lucia, Country.spain, Country.switzerland, Country.suriname, Country.united_kingdom, Country.venezuela]

        case .gabon: return [Country.cameroon, Country.republic_of_the_congo, Country.sao_tome_and_principe]
        case .gambia: return [Country.senegal]
        case .georgia: return [Country.armenia, Country.azerbaijan, Country.bulgaria, Country.russia, Country.turkey]
        case .germany: return [Country.austria, Country.belgium, Country.czech_republic, Country.denmark, Country.france, Country.luxembourg, Country.netherlands, Country.poland, Country.sweden, Country.switzerland, Country.united_kingdom]
        case .ghana: return [Country.burkina_faso, Country.ivory_coast, Country.togo]
        case .gibraltar: return [Country.spain]
        case .greece: return [Country.albania, Country.bulgaria, Country.cyprus, Country.egypt, Country.italy, Country.libya, Country.north_macedonia, Country.turkey]
        case .greenland: return [Country.canada, Country.iceland]
        case .grenada: return [Country.saint_vincent_and_the_grenadines, Country.trinidad_and_tobago, Country.venezuela]
        case .guam: return [Country.micronesia, Country.northern_mariana_islands]
        case .guatemala: return [Country.belize, Country.el_salvador, Country.honduras, Country.mexico]
        case .guernsey: return [Country.france, Country.jersey, Country.united_kingdom]
        case .guinea: return [Country.ivory_coast, Country.guinea_bissau, Country.liberia, Country.mali, Country.senegal, Country.sierra_leone]
        case .guinea_bissau: return [Country.guinea, Country.senegal]
        case .guyana: return [Country.barbados, Country.brazil, Country.suriname, Country.trinidad_and_tobago, Country.venezuela]

        case .haiti: return [Country.colombia, Country.cuba, Country.dominican_republic, Country.jamaica, Country.turks_and_caicos_islands]
        case .honduras: return [Country.belize, Country.cayman_islands, Country.cuba, Country.el_salvador, Country.guatemala, Country.jamaica, Country.mexico, Country.nicaragua]
        case .hong_kong: return [Country.china, Country.macau]
        case .hungary: return [Country.austria, Country.croatia, Country.romania, Country.serbia, Country.slovakia, Country.slovenia, Country.ukraine]

        case .iceland: return [Country.faroe_islands, Country.greenland]
        case .india: return [Country.bangladesh, Country.bhutan, Country.china, Country.indonesia, Country.maldives, Country.myanmar, Country.nepal, Country.pakistan, Country.sri_lanka, Country.thailand]
        case .indonesia: return [Country.australia, Country.china, Country.timor_leste, Country.india, Country.malaysia, Country.palau, Country.papua_new_guinea, Country.philippines, Country.singapore, Country.taiwan, Country.thailand, Country.vietnam]
        case .iran: return [Country.afghanistan, Country.armenia, Country.azerbaijan, Country.bahrain, Country.iraq, Country.kazakhstan, Country.kuwait, Country.oman, Country.pakistan, Country.qatar, Country.russia, Country.saudi_arabia, Country.turkey, Country.turkmenistan, Country.united_arab_emirates]
        case .iraq: return [Country.iran, Country.jordan, Country.kuwait, Country.saudi_arabia, Country.syria, Country.turkey]
        case .ireland: return [Country.united_kingdom]
        case .israel: return [Country.cyprus, Country.egypt, Country.jordan, Country.lebanon, Country.palestine, Country.syria]
        case .italy: return [Country.albania, Country.algeria, Country.austria, Country.croatia, Country.france, Country.greece, Country.libya, Country.malta, Country.montenegro, Country.san_marino, Country.slovenia, Country.spain, Country.switzerland, Country.tunisia, Country.vatican_city]

        case .jamaica: return [Country.cayman_islands, Country.colombia, Country.cuba, Country.haiti, Country.honduras, Country.nicaragua]
        case .japan: return [Country.china, Country.palau, Country.philippines, Country.russia, Country.south_korea, Country.northern_mariana_islands, Country.taiwan]
        case .jersey: return [Country.france, Country.guernsey]
        case .jordan: return [Country.egypt, Country.iraq, Country.israel, Country.palestine, Country.saudi_arabia, Country.syria]

        case .kazakhstan: return [Country.azerbaijan, Country.china, Country.kyrgyzstan, Country.russia, Country.turkmenistan, Country.uzbekistan]
        case .kenya: return [Country.ethiopia, Country.somalia, Country.south_sudan, Country.tanzania, Country.uganda]
        case .kiribati: return [Country.cook_islands, Country.marshall_islands, Country.nauru, Country.tokelau, Country.tuvalu]
        case .kosovo: return [Country.albania, Country.montenegro, Country.north_macedonia, Country.serbia]
        case .kuwait: return [Country.iran, Country.iraq, Country.saudi_arabia]
        case .kyrgyzstan: return [Country.china, Country.kazakhstan, Country.tajikistan, Country.uzbekistan]

        case .laos: return [Country.cambodia, Country.china, Country.myanmar, Country.thailand, Country.vietnam]
        case .latvia: return [Country.belarus, Country.estonia, Country.lithuania, Country.russia, Country.sweden]
        case .lebanon: return [Country.cyprus, Country.israel, Country.syria]
        case .lesotho: return [Country.south_africa]
        case .liberia: return [Country.guinea, Country.ivory_coast, Country.sierra_leone]
        case .libya: return [Country.algeria, Country.chad, Country.egypt, Country.greece, Country.italy, Country.malta, Country.niger, Country.sudan, Country.tunisia, Country.turkey]
        case .liechtenstein: return [Country.austria, Country.switzerland]
        case .lithuania: return [Country.belarus, Country.latvia, Country.poland, Country.russia, Country.sweden]
        case .luxembourg: return [Country.belgium, Country.france, Country.germany]

        case .macau: return [Country.china, Country.hong_kong]
        case .madagascar: return [Country.comoros, Country.france, Country.mauritius, Country.mozambique, Country.seychelles]
        case .malawi: return [Country.mozambique, Country.tanzania, Country.zambia]
        case .malaysia: return [Country.brunei, Country.china, Country.indonesia, Country.philippines, Country.singapore, Country.taiwan, Country.thailand]
        case .maldives: return [Country.india, Country.sri_lanka]
        case .mali: return [Country.algeria, Country.burkina_faso, Country.ivory_coast, Country.guinea, Country.mauritania, Country.niger, Country.senegal]
        case .malta: return [Country.italy, Country.libya, Country.tunisia]
        case .marshall_islands: return [Country.kiribati, Country.micronesia, Country.nauru]
        case .mauritania: return [Country.algeria, Country.cape_verde, Country.mali, Country.senegal, Country.western_sahara]
        case .mauritius: return [Country.france, Country.madagascar, Country.seychelles]
        case .mexico: return [Country.belize, Country.cuba, Country.guatemala, Country.honduras, Country.united_states]
        case .micronesia: return [Country.guam, Country.marshall_islands, Country.palau, Country.papua_new_guinea]
        case .moldova: return [Country.romania, Country.ukraine]
        case .monaco: return [Country.france]
        case .mongolia: return [Country.china, Country.russia]
        case .montenegro: return [Country.albania, Country.bosnia_and_herzegovina, Country.croatia, Country.italy, Country.kosovo, Country.serbia]
        case .montserrat: return [Country.antigua_and_barbuda, Country.france, Country.saint_kitts_and_nevis, Country.venezuela]
        case .morocco: return [Country.algeria, Country.portugal, Country.spain, Country.western_sahara]
        case .mozambique: return [Country.comoros, Country.eswatini, Country.madagascar, Country.malawi, Country.south_africa, Country.tanzania, Country.zambia, Country.zimbabwe]
        case .myanmar: return [Country.bangladesh, Country.china, Country.india, Country.laos, Country.thailand]

        case .namibia: return [Country.angola, Country.botswana, Country.south_africa, Country.zambia]
        case .nauru: return [Country.kiribati, Country.marshall_islands]
        case .nepal: return [Country.china, Country.india]

        case .netherlands: return [Country.anguilla, Country.belgium, Country.germany, Country.saint_barthelemy, Country.saint_martin, Country.united_kingdom, Country.venezuela]
        case .new_zealand: return [Country.australia, Country.fiji, Country.norfolk_island]
        case .nicaragua: return [Country.colombia, Country.costa_rica, Country.el_salvador, Country.honduras, Country.jamaica, Country.panama]
        case .niger: return [Country.algeria, Country.benin, Country.burkina_faso, Country.chad, Country.libya, Country.mali, Country.nigeria]
        case .nigeria: return [Country.benin, Country.cameroon, Country.chad, Country.niger, Country.sao_tome_and_principe]
        case .niue: return [Country.american_samoa, Country.cook_islands, Country.tonga]
        case .norfolk_island: return [Country.new_zealand]
        case .north_korea: return [Country.china, Country.south_korea, Country.russia]
        case .north_macedonia: return [Country.albania, Country.bulgaria, Country.greece, Country.kosovo, Country.serbia]
        case .northern_cyprus: return [Country.cyprus, Country.syria, Country.turkey]
        case .northern_mariana_islands: return [Country.guam, Country.japan]
        case .norway: return [Country.denmark, Country.faroe_islands, Country.finland, Country.russia, Country.sweden, Country.united_kingdom]

        case .oman: return [Country.iran, Country.pakistan, Country.saudi_arabia, Country.united_arab_emirates, Country.yemen]

        case .pakistan: return [Country.afghanistan, Country.china, Country.india, Country.iran, Country.oman]
        case .palau: return [Country.indonesia, Country.japan, Country.micronesia, Country.philippines]
        case .palestine: return [Country.egypt, Country.israel, Country.jordan]
        case .panama: return [Country.colombia, Country.costa_rica, Country.nicaragua]
        case .papua_new_guinea: return [Country.australia, Country.indonesia, Country.micronesia, Country.solomon_islands]
        case .paraguay: return [Country.argentina, Country.bolivia, Country.brazil]
        case .peru: return [Country.bolivia, Country.brazil, Country.chile, Country.colombia, Country.ecuador]
        case .philippines: return [Country.brunei, Country.china, Country.indonesia, Country.japan, Country.malaysia, Country.palau, Country.taiwan, Country.vietnam]
        case .poland: return [Country.belarus, Country.czech_republic, Country.denmark, Country.germany, Country.lithuania, Country.russia, Country.slovakia, Country.sweden, Country.ukraine]
        case .portugal: return [Country.morocco, Country.spain]
        case .puerto_rico: return [Country.british_virgin_islands, Country.dominican_republic, Country.venezuela]

        case .qatar: return [Country.bahrain, Country.iran, Country.saudi_arabia, Country.united_arab_emirates]

        case .romania: return [Country.bulgaria, Country.hungary, Country.moldova, Country.russia, Country.serbia, Country.ukraine]
        case .russia: return [Country.azerbaijan, Country.belarus, Country.china, Country.estonia, Country.finland, Country.georgia, Country.iran, Country.japan, Country.kazakhstan, Country.north_korea, Country.latvia, Country.lithuania, Country.mongolia, Country.norway, Country.poland, Country.romania, Country.sweden, Country.turkey, Country.ukraine, Country.united_states]
        case .rwanda: return [Country.burundi, Country.democratic_republic_of_the_congo, Country.tanzania, Country.uganda]

        case .saint_barthelemy: return [Country.anguilla, Country.antigua_and_barbuda, Country.netherlands, Country.saint_kitts_and_nevis, Country.saint_martin]
        case .saint_helena_ascension_and_tristan_da_cunha: return nil
        case .saint_kitts_and_nevis: return [Country.antigua_and_barbuda, Country.montserrat, Country.netherlands, Country.saint_barthelemy, Country.venezuela]
        case .saint_lucia: return [Country.barbados, Country.france, Country.saint_vincent_and_the_grenadines, Country.venezuela]
        case .saint_pierre_and_miquelon: return [Country.canada]
        case .saint_martin: return [Country.anguilla, Country.netherlands, Country.saint_barthelemy]
        case .saint_vincent_and_the_grenadines: return [Country.barbados, Country.grenada, Country.saint_lucia, Country.trinidad_and_tobago, Country.venezuela]
        case .samoa: return [Country.american_samoa, Country.tokelau, Country.tonga, Country.wallis_and_futuna]
        case .san_marino: return [Country.italy]
        case .sao_tome_and_principe: return [Country.gabon, Country.nigeria]
        case .saudi_arabia: return [Country.bahrain, Country.egypt, Country.eritrea, Country.iran, Country.iraq, Country.jordan, Country.kuwait, Country.oman, Country.qatar, Country.sudan, Country.united_arab_emirates, Country.yemen]
        case .senegal: return [Country.cape_verde, Country.gambia, Country.guinea, Country.guinea_bissau, Country.mali, Country.mauritania]
        case .serbia: return [Country.bosnia_and_herzegovina, Country.bulgaria, Country.croatia, Country.hungary, Country.kosovo, Country.montenegro, Country.north_macedonia, Country.romania]
        case .seychelles: return [Country.comoros, Country.madagascar, Country.mauritius, Country.tanzania]
        case .sierra_leone: return [Country.guinea, Country.liberia]
        case .singapore: return [Country.indonesia, Country.malaysia]
        case .slovakia: return [Country.austria, Country.czech_republic, Country.hungary, Country.poland, Country.ukraine]
        case .slovenia: return [Country.austria, Country.croatia, Country.italy, Country.hungary]
        case .solomon_islands: return [Country.fiji, Country.papua_new_guinea, Country.vanuatu]
        case .somalia: return [Country.djibouti, Country.ethiopia, Country.kenya, Country.yemen]
        case .somaliland: return [Country.djibouti, Country.ethiopia, Country.somalia, Country.yemen]
        case .south_africa: return [Country.botswana, Country.eswatini, Country.lesotho, Country.mozambique, Country.namibia, Country.zimbabwe]
        case .south_korea: return [Country.china, Country.japan, Country.north_korea]
        case .south_sudan: return [Country.central_african_republic, Country.democratic_republic_of_the_congo, Country.ethiopia, Country.kenya, Country.sudan, Country.uganda]
        case .spain: return [Country.algeria, Country.andorra, Country.france, Country.italy, Country.gibraltar, Country.morocco, Country.portugal, Country.western_sahara]
        case .sri_lanka: return [Country.india, Country.maldives]
        case .sudan: return [Country.central_african_republic, Country.chad, Country.egypt, Country.eritrea, Country.ethiopia, Country.libya, Country.saudi_arabia, Country.south_sudan]
        case .suriname: return [Country.brazil, Country.france, Country.guyana]
        case .sweden: return [Country.denmark, Country.estonia, Country.finland, Country.germany, Country.latvia, Country.lithuania, Country.norway, Country.poland, Country.russia]
        case .switzerland: return [Country.austria, Country.france, Country.italy, Country.liechtenstein, Country.germany]
        case .syria: return [Country.cyprus, Country.iraq, Country.israel, Country.jordan, Country.lebanon, Country.northern_cyprus, Country.turkey]
        case .taiwan: return [Country.brunei, Country.china, Country.indonesia, Country.japan, Country.malaysia, Country.philippines, Country.vietnam]
        case .tajikistan: return [Country.afghanistan, Country.china, Country.kyrgyzstan, Country.uzbekistan]
        case .tanzania: return [Country.burundi, Country.comoros, Country.democratic_republic_of_the_congo, Country.kenya, Country.malawi, Country.mozambique, Country.rwanda, Country.seychelles, Country.uganda, Country.zambia]
        case .thailand: return [Country.cambodia, Country.india, Country.indonesia, Country.laos, Country.malaysia, Country.myanmar, Country.vietnam]
        case .togo: return [Country.benin, Country.burkina_faso, Country.ghana]
        case .tokelau: return [Country.american_samoa, Country.cook_islands, Country.kiribati, Country.samoa, Country.wallis_and_futuna]
        case .tonga: return [Country.american_samoa, Country.fiji, Country.niue, Country.samoa, Country.wallis_and_futuna]
        case .transnistria: return [Country.moldova, Country.ukraine]
        case .trinidad_and_tobago: return [Country.barbados, Country.grenada, Country.guyana, Country.saint_vincent_and_the_grenadines, Country.venezuela]
        case .tunisia: return [Country.algeria, Country.italy, Country.libya, Country.malta]
        case .turkey: return [Country.armenia, Country.azerbaijan, Country.bulgaria, Country.cyprus, Country.egypt, Country.georgia, Country.greece, Country.iran, Country.iraq, Country.northern_cyprus, Country.russia, Country.syria, Country.ukraine, Country.libya]
        case .turkmenistan: return [Country.afghanistan, Country.azerbaijan, Country.iran, Country.kazakhstan, Country.uzbekistan]
        case .turks_and_caicos_islands: return [Country.bahamas, Country.dominican_republic, Country.haiti]
        case .tuvalu: return [Country.fiji, Country.kiribati, Country.wallis_and_futuna]

        case .uganda: return [Country.democratic_republic_of_the_congo, Country.kenya, Country.rwanda, Country.south_sudan, Country.tanzania]
        case .ukraine: return [Country.belarus, Country.hungary, Country.moldova, Country.poland, Country.romania, Country.russia, Country.slovakia, Country.turkey]
        case .united_arab_emirates: return [Country.iran, Country.oman, Country.qatar, Country.saudi_arabia]
        case .united_kingdom: return [Country.belgium, Country.denmark, Country.faroe_islands, Country.france, Country.germany, Country.guernsey, Country.ireland, Country.netherlands, Country.norway, Country.spain]
        case .united_states: return [Country.bahamas, Country.canada, Country.cuba, Country.mexico, Country.russia]
        case .uruguay: return [Country.argentina, Country.brazil]
        case .uzbekistan: return [Country.afghanistan, Country.kazakhstan, Country.kyrgyzstan, Country.tajikistan, Country.turkmenistan]

        case .vanuatu: return [Country.fiji, Country.solomon_islands]
        case .vatican_city: return [Country.italy]
        case .venezuela: return [Country.aruba, Country.barbados, Country.brazil, Country.colombia, Country.dominica, Country.dominican_republic, Country.france, Country.grenada, Country.guyana, Country.montserrat, Country.netherlands, Country.puerto_rico, Country.saint_kitts_and_nevis, Country.saint_lucia, Country.saint_vincent_and_the_grenadines, Country.trinidad_and_tobago]
        case .vietnam: return [Country.brunei, Country.cambodia, Country.china, Country.indonesia, Country.laos, Country.malaysia, Country.philippines, Country.taiwan, Country.thailand]

        case .wallis_and_futuna: return [Country.fiji, Country.samoa, Country.tonga, Country.tuvalu, Country.tokelau]
        case .western_sahara: return [Country.algeria, Country.mauritania, Country.morocco, Country.spain]

        case .yemen: return [Country.djibouti, Country.eritrea, Country.oman, Country.saudi_arabia, Country.somalia]

        case .zambia: return [Country.angola, Country.botswana, Country.democratic_republic_of_the_congo, Country.malawi, Country.mozambique, Country.namibia, Country.tanzania, Country.zimbabwe]
        case .zimbabwe: return [Country.botswana, Country.mozambique, Country.south_africa, Country.zambia]
        default: return nil
        }
    }
    
}
